/**
 * a map can be used to store entries, i.e., key-value pairs. 
 * for each key there may be at most one value which is stored. 
 */
public interface Map {
    /**
     * returns the number of key-value pairs that are stored in this map
     */
    public int size();
    /**
     * assigns the value to the key. if there already is an old entry for the key, 
     * then this old entry will be overwritten 
     * @param key the key for the entry 
     * @param value the value for the entry
     * @return true iff the entry has been stored (this might not be possible due to size restrictions) 
     */
    public boolean put(String key, String value);
    /**
     * returns the value that is stored under the given key
     * @return the value that is stored under the given key, or null, if there is
     *  no value stored under the given key
     */
    public String get(String key);
    /**
     * returns an iterator over all keys of this map
     */
    public Iterator keys();
    /**
     * adds all entries from otherMap to this map. if a key occurs on this map and
     * in otherMap, then the entry from the otherMap is taken
     * @return true iff all entries of otherMap could be stored into this map
     */
    public boolean putAll(Map otherMap);
    /**
     * returns a representation of this map in the format
     * (key1 -> value1, key2 -> value2, ...) 
     */
    public String toString();
        
}
